@@ -5,9 +5,12 @@
 # 
 use strict;
 use warnings;
+use utf8;
+use feature "unicode_strings";
 
 use Data::Dumper;
 use Getopt::Long;
+use File::Basename qw(dirname);
 
 my $help    = 0;
 my $details = 0;
@@ -23,8 +26,8 @@ if ($help) {
 
 # get the list of countries
 my %countries;
-my $country_file = "../conf/country_codes.yaml";
-open my $FH, "<", $country_file or die "unable to open $country_file $!";
+my $country_file = dirname(__FILE__) . "/../conf/country_codes.yaml";
+open my $FH, "<:encoding(UTF-8)", $country_file or die "unable to open $country_file $!";
 while (my $line = <$FH>){
     chomp($line);
     if ($line =~ m/^(\w\w): \# (.*)$/){
@@ -32,11 +35,12 @@ while (my $line = <$FH>){
     }
 }
 close $FH;
-print "We are aware of " . scalar(keys %countries) . " territories \n";
+my $total_countries = scalar(keys %countries); 
+print "We are aware of " . $total_countries . " territories \n";
 
 
 # which countries have tests?
-my $test_dir = '../testcases/countries';
+my $test_dir = dirname(__FILE__) . '/../testcases/countries';
 opendir(my $dh, $test_dir) || die "Error: Couldn't opendir($test_dir): $!\n";
 my @files = grep { -f "$test_dir/$_" } readdir($dh);
 closedir($dh);
@@ -47,7 +51,10 @@ foreach my $f (sort @files){
     $f = uc($f);
     $test_countries{$f} = 1;
 }
-print "We have tests for " . scalar(keys %test_countries) . " territories \n";
+my $test_countries = scalar(keys %test_countries);
+my $test_perc = int(100 * $test_countries / $total_countries );
+print "We have tests for " .  $test_countries . ' ('
+    . $test_perc . '%) territories' .  "\n";
 if ($details){
     print "We need tests for:\n";
     foreach my $cc (sort keys %countries){
@@ -57,8 +64,8 @@ if ($details){
 }
 
 # which countries have rules?
-my $rules_file = '../conf/countries/worldwide.yaml';
-open my $RFH, "<", $rules_file or die "unable to open $rules_file $!";
+my $rules_file = dirname(__FILE__) . '/../conf/countries/worldwide.yaml';
+open my $RFH, "<:encoding(UTF-8)", $rules_file or die "unable to open $rules_file $!";
 my %rules;
 while (my $line = <$RFH>){
     chomp($line);
@@ -67,7 +74,11 @@ while (my $line = <$RFH>){
     }
 }
 close $RFH;
-print "We have rules for " . scalar(keys %rules) . " territories \n";
+my $rules_countries = scalar(keys %rules);
+my $rules_perc = int(100 * $rules_countries / $total_countries );
+print "We have rules for " .  $rules_countries . ' ('
+    . $rules_perc . '%) territories' . "\n";
+
 if ($details){
     print "We need rules for:\n";
     foreach my $cc (sort keys %countries){
@@ -76,7 +87,6 @@ if ($details){
     }
 }
 
-
 # find territories without rules or tests
 my %neither;
 foreach my $cc (sort keys %countries){
@@ -84,7 +94,9 @@ foreach my $cc (sort keys %countries){
     next if (defined($test_countries{$cc}));
     $neither{$cc} = 1;
 }
-print scalar(keys %neither) . " territories have neither rules nor tests\n";
+my $neither_countries = scalar(keys %neither);
+my $neither_perc = int(100 * $neither_countries / $total_countries );
+print $neither_countries . ' (' . $neither_perc . '%) territories have neither rules nor tests' . "\n";
 if ($details){
     print "Territories with no test and no rules:\n";
     foreach my $cc (sort keys %neither){
@@ -93,10 +105,6 @@ if ($details){
 }
 
 
-
-
-
-
 sub usage {
     print "\tHow many territories have formatting rules and tests?\n";
     print "\tBy default prints just a high level summary\n";
